# xmlmerge

XMLMerge is simple tool to merge multiple xml files.

## How to Install

```bash
pip install xmlmerge
```

## Usage

```bash
$xmlmerge file1.xml file2.xml > file3.xml
$xmlmerge tests/*.xml > combine.xml
```

## How end file looks like

```xml
<products>
    <product id="9999">
        <a>1234</a>
        <b>1234</b>
    </product>
<product id="5678">
        <a>1234</a>
        <b>1234</b>
    </product>
</products>

```

## Contact

Contact Kiran Kumar Kotari <kirankotari@live.com> with any suggestions or comments. If you find any bugs please fix them and send me a pull request.
